@@ -1,5 +1,5 @@
 /**
- * SPDX-FileCopyrightText: 2020 Tobias Fella <fella@posteo.de>
+ * SPDX-FileCopyrightText: 2020 Tobias Fella <tobias.fella@kde.org>
  *
  * SPDX-License-Identifier: GPL-2.0-only OR GPL-3.0-only OR LicenseRef-KDE-Accepted-GPL
  */
@@ -8,12 +8,15 @@
 
 #include <QNetworkAccessManager>
 #include <QObject>
+#include <QQmlEngine>
 #include <QUrl>
 #include <Syndication/Syndication>
 
 class Fetcher : public QObject
 {
     Q_OBJECT
+    QML_ELEMENT
+    QML_SINGLETON
 
     Q_PROPERTY(bool refreshing READ refreshing NOTIFY refreshingChanged)
 
@@ -23,6 +26,11 @@ public:
         static Fetcher _instance;
         return _instance;
     }
+
+    static Fetcher *create(QQmlEngine *, QJSEngine *)
+    {
+        return &instance();
+    }
     Q_INVOKABLE void fetch(const QString &url, const bool markEntriesRead = false);
     Q_INVOKABLE void fetchAll();
     Q_INVOKABLE QString image(const QString &url);
